@@ -14,7 +14,7 @@ class Field:
         self._name = None
         self._model = None
 
-    def adapt(self, value):
+    def adapt(self, value):  # pylint: disable=no-self-use
         return value
 
     def adapt_value(self, value):
@@ -23,7 +23,7 @@ class Field:
 
         return self.adapt(value)
 
-    def to_query_parameter(self, value):
+    def to_query_parameter(self, value):  # pylint: disable=no-self-use
         return value
 
     def render_sql(self):
@@ -150,7 +150,7 @@ class DateTimeField(Field):
 class AutoField(Field):
 
     def __init__(self, pk=False, null=False, unique=False, default=None, column_name=None):
-        super(AutoField, self).__init__(pk=pk, null=null, unique=unique, default=default, column_name=column_name)
+        super().__init__(pk=pk, null=null, unique=unique, default=default, column_name=column_name)
         self._null = self.is_pk
         self._unique = False
 
@@ -167,6 +167,7 @@ class AutoField(Field):
 class ForeignKey(Field):
 
     def __init__(self, to, pk=False, null=False, unique=False, default=None, column_name=None):
+        # pylint: disable=too-many-arguments
         if not column_name:
             column_name = f"{to._meta.table_name}_id"
 
@@ -185,3 +186,24 @@ class ForeignKey(Field):
         ref_pk_field = self.to._meta.pk_field
         fk_type = 'INTEGER' if isinstance(ref_pk_field, AutoField) else ref_pk_field.render_sql_type()
         return f'{fk_type} REFERENCES {self.to._meta.table_name} ({ref_pk_field.name})'
+
+    def __set__(self, instance, value):
+        setattr(instance, self.raw_fk_attr, self.to_query_parameter(value))
+        if isinstance(value, self.to):
+            setattr(instance, self.cached_instance_attr, value)
+
+    def __get__(self, instance, owner):
+        if not hasattr(instance, self.cached_instance_attr):
+            raw_fk_value = getattr(instance, self.raw_fk_attr)
+            fetched_instance = self.to.qs.get(pk=raw_fk_value)
+            setattr(instance, self.cached_instance_attr, fetched_instance)
+
+        return getattr(instance, self.cached_instance_attr)
+
+    @property
+    def raw_fk_attr(self):
+        return f'{self.name}_id'
+
+    @property
+    def cached_instance_attr(self):
+        return f'_{self.name}_cached'
